# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from tetherhelix_grpc import tetherbot_pb2 as tetherhelix__grpc_dot_tetherbot__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in tetherhelix_grpc/tetherbot_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TetherBotStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentPositions = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/GetCurrentPositions',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.FromString,
                _registered_method=True)
        self.StreamRealTimePositions = channel.unary_stream(
                '/tetherhelix_grpc.TetherBot/StreamRealTimePositions',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.FromString,
                _registered_method=True)
        self.StreamMarketValue = channel.unary_stream(
                '/tetherhelix_grpc.TetherBot/StreamMarketValue',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.FromString,
                _registered_method=True)
        self.Start = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/Start',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
                _registered_method=True)
        self.Stop = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/Stop',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
                _registered_method=True)


class TetherBotServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCurrentPositions(self, request, context):
        """트레이딩 봇이 실시간 가격 데이터를 스트리밍함
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRealTimePositions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamMarketValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TetherBotServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentPositions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentPositions,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.SerializeToString,
            ),
            'StreamRealTimePositions': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamRealTimePositions,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.SerializeToString,
            ),
            'StreamMarketValue': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamMarketValue,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tetherhelix_grpc.TetherBot', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('tetherhelix_grpc.TetherBot', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TetherBot(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCurrentPositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/GetCurrentPositions',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamRealTimePositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/StreamRealTimePositions',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamMarketValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/StreamMarketValue',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/Start',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/Stop',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LoginRequest(_message.Message):
    __slots__ = ("admin_certificate",)
    ADMIN_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    admin_certificate: str
    def __init__(self, admin_certificate: _Optional[str] = ...) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ("success", "message", "db_auth")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    db_auth: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ..., db_auth: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/admin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctetherhelix_grpc/admin.proto\x12\x10tetherhelix_grpc\")\n\x0cLoginRequest\x12\x19\n\x11\x61\x64min_certificate\x18\x01 \x01(\t\"B\n\rLoginResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_auth\x18\x03 \x01(\t2U\n\tAdminAuth\x12H\n\x05Login\x12\x1e.tetherhelix_grpc.LoginRequest\x1a\x1f.tetherhelix_grpc.LoginResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_LOGINREQUEST']._serialized_start=50
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=159
  _globals['_ADMINAUTH']._serialized_start=161
  _globals['_ADMINAUTH']._serialized_end=246
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Position(_message.Message):
    __slots__ = ("timestamp", "bid_order_uuid", "entry_price", "volume", "ask_order_uuid", "created_at", "target_price")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    BID_ORDER_UUID_FIELD_NUMBER: _ClassVar[int]
    ENTRY_PRICE_FIELD_NUMBER: _ClassVar[int]
    VOLUME_FIELD_NUMBER: _ClassVar[int]
    ASK_ORDER_UUID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    TARGET_PRICE_FIELD_NUMBER: _ClassVar[int]
    timestamp: int
    bid_order_uuid: str
    entry_price: float
    volume: float
    ask_order_uuid: str
    created_at: str
    target_price: float
    def __init__(self, timestamp: _Optional[int] = ..., bid_order_uuid: _Optional[str] = ..., entry_price: _Optional[float] = ..., volume: _Optional[float] = ..., ask_order_uuid: _Optional[str] = ..., created_at: _Optional[str] = ..., target_price: _Optional[float] = ...) -> None: ...

class KeyRequest(_message.Message):
    __slots__ = ("db_auth",)
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    def __init__(self, db_auth: _Optional[str] = ...) -> None: ...

class KeyResponse(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...

class BatchPositionsResponse(_message.Message):
    __slots__ = ("batch",)
    BATCH_FIELD_NUMBER: _ClassVar[int]
    batch: _containers.RepeatedCompositeFieldContainer[Position]
    def __init__(self, batch: _Optional[_Iterable[_Union[Position, _Mapping]]] = ...) -> None: ...

class PositionsResponse(_message.Message):
    __slots__ = ("position_idx", "position", "timestamp")
    POSITION_IDX_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    position_idx: int
    position: Position
    timestamp: str
    def __init__(self, position_idx: _Optional[int] = ..., position: _Optional[_Union[Position, _Mapping]] = ..., timestamp: _Optional[str] = ...) -> None: ...

class MarketDataResponse(_message.Message):
    __slots__ = ("price", "timestamp_epoch")
    PRICE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_EPOCH_FIELD_NUMBER: _ClassVar[int]
    price: float
    timestamp_epoch: int
    def __init__(self, price: _Optional[float] = ..., timestamp_epoch: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionData(_message.Message):
    __slots__ = ("bid_uuid", "bid_created_at", "bid_price", "bid_krw", "bid_fee", "bid_failed", "ask_failed", "order_status", "tether_volume", "bid_filled_at", "ask_uuid", "ask_created_at", "ask_filled_at", "ask_price", "ask_fee", "revenue")
    BID_UUID_FIELD_NUMBER: _ClassVar[int]
    BID_CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    BID_PRICE_FIELD_NUMBER: _ClassVar[int]
    BID_KRW_FIELD_NUMBER: _ClassVar[int]
    BID_FEE_FIELD_NUMBER: _ClassVar[int]
    BID_FAILED_FIELD_NUMBER: _ClassVar[int]
    ASK_FAILED_FIELD_NUMBER: _ClassVar[int]
    ORDER_STATUS_FIELD_NUMBER: _ClassVar[int]
    TETHER_VOLUME_FIELD_NUMBER: _ClassVar[int]
    BID_FILLED_AT_FIELD_NUMBER: _ClassVar[int]
    ASK_UUID_FIELD_NUMBER: _ClassVar[int]
    ASK_CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ASK_FILLED_AT_FIELD_NUMBER: _ClassVar[int]
    ASK_PRICE_FIELD_NUMBER: _ClassVar[int]
    ASK_FEE_FIELD_NUMBER: _ClassVar[int]
    REVENUE_FIELD_NUMBER: _ClassVar[int]
    bid_uuid: str
    bid_created_at: str
    bid_price: float
    bid_krw: float
    bid_fee: float
    bid_failed: int
    ask_failed: int
    order_status: int
    tether_volume: float
    bid_filled_at: str
    ask_uuid: str
    ask_created_at: str
    ask_filled_at: str
    ask_price: float
    ask_fee: str
    revenue: str
    def __init__(self, bid_uuid: _Optional[str] = ..., bid_created_at: _Optional[str] = ..., bid_price: _Optional[float] = ..., bid_krw: _Optional[float] = ..., bid_fee: _Optional[float] = ..., bid_failed: _Optional[int] = ..., ask_failed: _Optional[int] = ..., order_status: _Optional[int] = ..., tether_volume: _Optional[float] = ..., bid_filled_at: _Optional[str] = ..., ask_uuid: _Optional[str] = ..., ask_created_at: _Optional[str] = ..., ask_filled_at: _Optional[str] = ..., ask_price: _Optional[float] = ..., ask_fee: _Optional[str] = ..., revenue: _Optional[str] = ...) -> None: ...

class TransactionRequest(_message.Message):
    __slots__ = ("db_auth", "bot_name")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    BOT_NAME_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    bot_name: str
    def __init__(self, db_auth: _Optional[str] = ..., bot_name: _Optional[str] = ...) -> None: ...

class ScopedTransactionRequest(_message.Message):
    __slots__ = ("db_auth", "start_time", "end_time")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    start_time: int
    end_time: int
    def __init__(self, db_auth: _Optional[str] = ..., start_time: _Optional[int] = ..., end_time: _Optional[int] = ...) -> None: ...

class TransactionsResponse(_message.Message):
    __slots__ = ("transactions",)
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    transactions: _containers.RepeatedCompositeFieldContainer[TransactionData]
    def __init__(self, transactions: _Optional[_Iterable[_Union[TransactionData, _Mapping]]] = ...) -> None: ...

class DBCommitResponse(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...

class BidPlaceRequest(_message.Message):
    __slots__ = ("db_auth", "bid_uuid", "bid_price", "tether_volume")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    BID_UUID_FIELD_NUMBER: _ClassVar[int]
    BID_PRICE_FIELD_NUMBER: _ClassVar[int]
    TETHER_VOLUME_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    bid_uuid: str
    bid_price: float
    tether_volume: float
    def __init__(self, db_auth: _Optional[str] = ..., bid_uuid: _Optional[str] = ..., bid_price: _Optional[float] = ..., tether_volume: _Optional[float] = ...) -> None: ...

class BidFillRequest(_message.Message):
    __slots__ = ("db_auth", "bid_uuid")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    BID_UUID_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    bid_uuid: str
    def __init__(self, db_auth: _Optional[str] = ..., bid_uuid: _Optional[str] = ...) -> None: ...

class AskPlaceRequest(_message.Message):
    __slots__ = ("db_auth", "bid_uuid", "ask_uuid", "ask_price")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    BID_UUID_FIELD_NUMBER: _ClassVar[int]
    ASK_UUID_FIELD_NUMBER: _ClassVar[int]
    ASK_PRICE_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    bid_uuid: str
    ask_uuid: str
    ask_price: float
    def __init__(self, db_auth: _Optional[str] = ..., bid_uuid: _Optional[str] = ..., ask_uuid: _Optional[str] = ..., ask_price: _Optional[float] = ...) -> None: ...

class AskFillRequest(_message.Message):
    __slots__ = ("db_auth", "ask_uuid", "ask_fee")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    ASK_UUID_FIELD_NUMBER: _ClassVar[int]
    ASK_FEE_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    ask_uuid: str
    ask_fee: str
    def __init__(self, db_auth: _Optional[str] = ..., ask_uuid: _Optional[str] = ..., ask_fee: _Optional[str] = ...) -> None: ...

class UuidRequest(_message.Message):
    __slots__ = ("db_auth", "uuid")
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    uuid: str
    def __init__(self, db_auth: _Optional[str] = ..., uuid: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"tetherhelix_grpc/transaction.proto\x12\x10tetherhelix_grpc\"\xd2\x02\n\x0fTransactionData\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x15\n\rbid_filled_at\x18\n \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x0b \x01(\t\x12\x16\n\x0e\x61sk_created_at\x18\x0c \x01(\t\x12\x15\n\rask_filled_at\x18\r \x01(\t\x12\x11\n\task_price\x18\x0e \x01(\x02\x12\x0f\n\x07\x61sk_fee\x18\x0f \x01(\t\x12\x0f\n\x07revenue\x18\x10 \x01(\t\"7\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62ot_name\x18\x02 \x01(\t\"Q\n\x18ScopedTransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\"O\n\x14TransactionsResponse\x12\x37\n\x0ctransactions\x18\x01 \x03(\x0b\x32!.tetherhelix_grpc.TransactionData\"8\n\x10\x44\x42\x43ommitResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"^\n\x0f\x42idPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x15\n\rtether_volume\x18\x04 \x01(\x02\"3\n\x0e\x42idFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\"Y\n\x0f\x41skPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x03 \x01(\t\x12\x11\n\task_price\x18\x04 \x01(\x02\"D\n\x0e\x41skFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x61sk_fee\x18\x03 \x01(\t\",\n\x0bUuidRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xee\x05\n\x0bTransaction\x12\x66\n\x16GetCurrentTransactions\x12$.tetherhelix_grpc.TransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12i\n\x13GetPastTransactions\x12*.tetherhelix_grpc.ScopedTransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12R\n\tBidPlaced\x12!.tetherhelix_grpc.BidPlaceRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12Q\n\tBidFilled\x12 .tetherhelix_grpc.BidFillRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12R\n\tAskPlaced\x12!.tetherhelix_grpc.AskPlaceRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12Q\n\tAskFilled\x12 .tetherhelix_grpc.AskFillRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12^\n\x19OrderFailedAfterBidPlaced\x12\x1d.tetherhelix_grpc.UuidRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12^\n\x19OrderFailedAfterAskPlaced\x12\x1d.tetherhelix_grpc.UuidRequest\x1a\".tetherhelix_grpc.DBCommitResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_TRANSACTIONDATA']._serialized_start=57
  _globals['_TRANSACTIONDATA']._serialized_end=395
  _globals['_TRANSACTIONREQUEST']._serialized_start=397
  _globals['_TRANSACTIONREQUEST']._serialized_end=452
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_start=454
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_end=535
  _globals['_TRANSACTIONSRESPONSE']._serialized_start=537
  _globals['_TRANSACTIONSRESPONSE']._serialized_end=616
  _globals['_DBCOMMITRESPONSE']._serialized_start=618
  _globals['_DBCOMMITRESPONSE']._serialized_end=674
  _globals['_BIDPLACEREQUEST']._serialized_start=676
  _globals['_BIDPLACEREQUEST']._serialized_end=770
  _globals['_BIDFILLREQUEST']._serialized_start=772
  _globals['_BIDFILLREQUEST']._serialized_end=823
  _globals['_ASKPLACEREQUEST']._serialized_start=825
  _globals['_ASKPLACEREQUEST']._serialized_end=914
  _globals['_ASKFILLREQUEST']._serialized_start=916
  _globals['_ASKFILLREQUEST']._serialized_end=984
  _globals['_UUIDREQUEST']._serialized_start=986
  _globals['_UUIDREQUEST']._serialized_end=1030
  _globals['_TRANSACTION']._serialized_start=1033
  _globals['_TRANSACTION']._serialized_end=1783
# @@protoc_insertion_point(module_scope)
